==> vos-3.4.tar.gz: vos-3.4/vos/tests/test_commonparser.py <==
# ***********************************************************************
# ******************  CANADIAN ASTRONOMY DATA CENTRE  *******************
# *************  CENTRE CANADIEN DE DONNÉES ASTRONOMIQUES  **************
#
#  (c) 2022.                            (c) 2022.
#  Government of Canada                 Gouvernement du Canada
#  National Research Council            Conseil national de recherches
#  Ottawa, Canada, K1A 0R6              Ottawa, Canada, K1A 0R6
#  All rights reserved                  Tous droits réservés
#
#  NRC disclaims any warranties,        Le CNRC dénie toute garantie
#  expressed, implied, or               énoncée, implicite ou légale,
#  statutory, of any kind with          de quelque nature que ce
#  respect to the software,             soit, concernant le logiciel,
#  including without limitation         y compris sans restriction
#  any warranty of merchantability      toute garantie de valeur
#  or fitness for a particular          marchande ou de pertinence
#  purpose. NRC shall not be            pour un usage particulier.
#  liable in any event for any          Le CNRC ne pourra en aucun cas
#  damages, whether direct or           être tenu responsable de tout
#  indirect, special or general,        dommage, direct ou indirect,
#  consequential or incidental,         particulier ou général,
#  arising from the use of the          accessoire ou fortuit, résultant
#  software.  Neither the name          de l'utilisation du logiciel. Ni
#  of the National Research             le nom du Conseil National de
#  Council of Canada nor the            Recherches du Canada ni les noms
#  names of its contributors may        de ses  participants ne peuvent
#  be used to endorse or promote        être utilisés pour approuver ou
#  products derived from this           promouvoir les produits dérivés
#  software without specific prior      de ce logiciel sans autorisation
#  written permission.                  préalable et particulière
#                                       par écrit.
#
#  This file is part of the             Ce fichier fait partie du projet
#  OpenCADC project.                    OpenCADC.
#
#  OpenCADC is free software:           OpenCADC est un logiciel libre ;
#  you can redistribute it and/or       vous pouvez le redistribuer ou le
#  modify it under the terms of         modifier suivant les termes de
#  the GNU Affero General Public        la “GNU Affero General Public
#  License as published by the          License” telle que publiée
#  Free Software Foundation,            par la Free Software Foundation
#  either version 3 of the              : soit la version 3 de cette
#  License, or (at your option)         licence, soit (à votre gré)
#  any later version.                   toute version ultérieure.
#
#  OpenCADC is distributed in the       OpenCADC est distribué
#  hope that it will be useful,         dans l’espoir qu’il vous
#  but WITHOUT ANY WARRANTY;            sera utile, mais SANS AUCUNE
#  without even the implied             GARANTIE : sans même la garantie
#  warranty of MERCHANTABILITY          implicite de COMMERCIALISABILITÉ
#  or FITNESS FOR A PARTICULAR          ni d’ADÉQUATION À UN OBJECTIF
#  PURPOSE.  See the GNU Affero         PARTICULIER. Consultez la Licence
#  General Public License for           Générale Publique GNU Affero
#  more details.                        pour plus de détails.
#
#  You should have received             Vous devriez avoir reçu une
#  a copy of the GNU Affero             copie de la Licence Générale
#  General Public License along         Publique GNU Affero avec
#  with OpenCADC.  If not, see          OpenCADC ; si ce n’est
#  <http://www.gnu.org/licenses/>.      pas le cas, consultez :
#                                       <http://www.gnu.org/licenses/>.
#
#  $Revision: 4 $
#
# ***********************************************************************
#

import unittest
import sys
import logging
from vos.commonparser import CommonParser
from vos.commonparser import set_logging_level_from_args, exit_on_exception
from vos.version import version
from mock import patch, Mock
from io import StringIO


class TestCommonParser(unittest.TestCase):
    """Test the CommonParser class.
    """

    def test_all(self):
        """Test CommonParser."""
        common_parser = CommonParser()
        # hijack the arguments
        sys.argv = ['myapp', '-w']
        args = common_parser.parse_args()
        set_logging_level_from_args(args)
        self.assertEqual(version, common_parser.version)
        self.assertEqual(logging.WARNING, logging.getLogger('root').level)

        # Remove all handlers associated with the root logger object.
        for handler in logging.root.handlers[:]:
            logging.root.removeHandler(handler)
        common_parser = CommonParser()
        sys.argv = ['myapp', '-d']
        args = common_parser.parse_args()
        set_logging_level_from_args(args)
        self.assertEqual(logging.DEBUG, logging.getLogger().level)
        self.assertEqual(version, common_parser.version)

        common_parser = CommonParser()
        sys.argv = ['myapp', '--version']
        with patch('vos.commonparser.sys.exit', Mock()):
            common_parser.parse_args()

    def test_exit_on_exception(self):
        try:
            # Exceptions needs a context, hence raising it
            raise RuntimeError('Test')
        except Exception as e:
            with patch('sys.exit'):
                with patch('sys.stderr', new_callable=StringIO) as stderr_mock:
                    exit_on_exception(e)
            self.assertEqual('ERROR:: Test\n', stderr_mock.getvalue())

            with patch('sys.exit'):
                with patch('sys.stderr', new_callable=StringIO) as stderr_mock:
                    exit_on_exception(e, 'Error message')
            self.assertEqual('ERROR:: Error message\n', stderr_mock.getvalue())

==> vos-3.6rc0.tar.gz: vos-3.6rc0/vos/tests/test_commonparser.py <==
# ***********************************************************************
# ******************  CANADIAN ASTRONOMY DATA CENTRE  *******************
# *************  CENTRE CANADIEN DE DONNÉES ASTRONOMIQUES  **************
#
#  (c) 2023.                            (c) 2023.
#  Government of Canada                 Gouvernement du Canada
#  National Research Council            Conseil national de recherches
#  Ottawa, Canada, K1A 0R6              Ottawa, Canada, K1A 0R6
#  All rights reserved                  Tous droits réservés
#
#  NRC disclaims any warranties,        Le CNRC dénie toute garantie
#  expressed, implied, or               énoncée, implicite ou légale,
#  statutory, of any kind with          de quelque nature que ce
#  respect to the software,             soit, concernant le logiciel,
#  including without limitation         y compris sans restriction
#  any warranty of merchantability      toute garantie de valeur
#  or fitness for a particular          marchande ou de pertinence
#  purpose. NRC shall not be            pour un usage particulier.
#  liable in any event for any          Le CNRC ne pourra en aucun cas
#  damages, whether direct or           être tenu responsable de tout
#  indirect, special or general,        dommage, direct ou indirect,
#  consequential or incidental,         particulier ou général,
#  arising from the use of the          accessoire ou fortuit, résultant
#  software.  Neither the name          de l'utilisation du logiciel. Ni
#  of the National Research             le nom du Conseil National de
#  Council of Canada nor the            Recherches du Canada ni les noms
#  names of its contributors may        de ses  participants ne peuvent
#  be used to endorse or promote        être utilisés pour approuver ou
#  products derived from this           promouvoir les produits dérivés
#  software without specific prior      de ce logiciel sans autorisation
#  written permission.                  préalable et particulière
#                                       par écrit.
#
#  This file is part of the             Ce fichier fait partie du projet
#  OpenCADC project.                    OpenCADC.
#
#  OpenCADC is free software:           OpenCADC est un logiciel libre ;
#  you can redistribute it and/or       vous pouvez le redistribuer ou le
#  modify it under the terms of         modifier suivant les termes de
#  the GNU Affero General Public        la “GNU Affero General Public
#  License as published by the          License” telle que publiée
#  Free Software Foundation,            par la Free Software Foundation
#  either version 3 of the              : soit la version 3 de cette
#  License, or (at your option)         licence, soit (à votre gré)
#  any later version.                   toute version ultérieure.
#
#  OpenCADC is distributed in the       OpenCADC est distribué
#  hope that it will be useful,         dans l’espoir qu’il vous
#  but WITHOUT ANY WARRANTY;            sera utile, mais SANS AUCUNE
#  without even the implied             GARANTIE : sans même la garantie
#  warranty of MERCHANTABILITY          implicite de COMMERCIALISABILITÉ
#  or FITNESS FOR A PARTICULAR          ni d’ADÉQUATION À UN OBJECTIF
#  PURPOSE.  See the GNU Affero         PARTICULIER. Consultez la Licence
#  General Public License for           Générale Publique GNU Affero
#  more details.                        pour plus de détails.
#
#  You should have received             Vous devriez avoir reçu une
#  a copy of the GNU Affero             copie de la Licence Générale
#  General Public License along         Publique GNU Affero avec
#  with OpenCADC.  If not, see          OpenCADC ; si ce n’est
#  <http://www.gnu.org/licenses/>.      pas le cas, consultez :
#                                       <http://www.gnu.org/licenses/>.
#
#  $Revision: 4 $
#
# ***********************************************************************
#

import unittest
import sys
import logging
from vos.commonparser import CommonParser
from vos.commonparser import set_logging_level_from_args, exit_on_exception
from vos.version import version
from unittest.mock import patch, Mock
from io import StringIO


class TestCommonParser(unittest.TestCase):
    """Test the CommonParser class.
    """

    def test_all(self):
        """Test CommonParser."""
        common_parser = CommonParser()
        # hijack the arguments
        sys.argv = ['myapp', '-w']
        args = common_parser.parse_args()
        set_logging_level_from_args(args)
        self.assertEqual(version, common_parser.version)
        self.assertEqual(logging.WARNING, logging.getLogger('root').level)

        # Remove all handlers associated with the root logger object.
        for handler in logging.root.handlers[:]:
            logging.root.removeHandler(handler)
        common_parser = CommonParser()
        sys.argv = ['myapp', '-d']
        args = common_parser.parse_args()
        set_logging_level_from_args(args)
        self.assertEqual(logging.DEBUG, logging.getLogger().level)
        self.assertEqual(version, common_parser.version)

        common_parser = CommonParser()
        sys.argv = ['myapp', '--version']
        with patch('vos.commonparser.sys.exit', Mock()):
            common_parser.parse_args()

    def test_exit_on_exception(self):
        try:
            # Exceptions needs a context, hence raising it
            raise RuntimeError('Test')
        except Exception as e:
            with patch('sys.exit'):
                with patch('sys.stderr', new_callable=StringIO) as stderr_mock:
                    exit_on_exception(e)
            self.assertEqual('ERROR:: Test\n', stderr_mock.getvalue())

            with patch('sys.exit'):
                with patch('sys.stderr', new_callable=StringIO) as stderr_mock:
                    exit_on_exception(e, 'Error message')
            self.assertEqual('ERROR:: Error message\n', stderr_mock.getvalue())
